# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.project_templates_api import ProjectTemplatesApi  # noqa: E501
from asana.rest import ApiException


class TestProjectTemplatesApi(unittest.TestCase):
    """ProjectTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = ProjectTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_project_template(self):
        """Test case for delete_project_template

        Delete a project template  # noqa: E501
        """
        pass

    def test_get_project_template(self):
        """Test case for get_project_template

        Get a project template  # noqa: E501
        """
        pass

    def test_get_project_templates(self):
        """Test case for get_project_templates

        Get multiple project templates  # noqa: E501
        """
        pass

    def test_get_project_templates_for_team(self):
        """Test case for get_project_templates_for_team

        Get a team's project templates  # noqa: E501
        """
        pass

    def test_instantiate_project(self):
        """Test case for instantiate_project

        Instantiate a project from a project template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
