# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.goals_api import GoalsApi  # noqa: E501
from asana.rest import ApiException


class TestGoalsApi(unittest.TestCase):
    """GoalsApi unit test stubs"""

    def setUp(self):
        self.api = GoalsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_followers(self):
        """Test case for add_followers

        Add a collaborator to a goal  # noqa: E501
        """
        pass

    def test_create_goal(self):
        """Test case for create_goal

        Create a goal  # noqa: E501
        """
        pass

    def test_create_goal_metric(self):
        """Test case for create_goal_metric

        Create a goal metric  # noqa: E501
        """
        pass

    def test_delete_goal(self):
        """Test case for delete_goal

        Delete a goal  # noqa: E501
        """
        pass

    def test_get_goal(self):
        """Test case for get_goal

        Get a goal  # noqa: E501
        """
        pass

    def test_get_goals(self):
        """Test case for get_goals

        Get goals  # noqa: E501
        """
        pass

    def test_get_parent_goals_for_goal(self):
        """Test case for get_parent_goals_for_goal

        Get parent goals from a goal  # noqa: E501
        """
        pass

    def test_remove_followers(self):
        """Test case for remove_followers

        Remove a collaborator from a goal  # noqa: E501
        """
        pass

    def test_update_goal(self):
        """Test case for update_goal

        Update a goal  # noqa: E501
        """
        pass

    def test_update_goal_metric(self):
        """Test case for update_goal_metric

        Update a goal metric  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
